package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`/@`!````\"5``#0```!$LP```````#0`(``,
M`"@`'``;``8````T````-`!``#0`0`"``0``@`$```0````$`````P```+0!
M``"T`4``M`%``!H````:````!`````$````!````````````0````$``0!(`
M`$`2```$`````!````$`````(````"!````@0`!U-0``=34```4`````$```
M`0````!@````8$```&!``,!%``#`10``!``````0```!````<*X``'"^0`!P
MOD``>`,``,03```&`````!````(```!XK@``>+Y``'B^0``0`0``$`$```8`
M```$````!````-`!``#0`4``T`%``'@```!X````!`````0```!3Y71D]`$`
M`/0!0`#T`4``-````#0````$````!````%#E=&18GP``6)]``%B?0`#4````
MU`````0````$````4>5T9```````````````````````````!@```!````!2
MY71D<*X``'"^0`!POD``D`$``)`!```$`````0```"]L:6)X,S(O;&0M;&EN
M=7@M>#,R+G-O+C(````$````%`````,```!'3E4`!%>Y2YD?JP&<F`?P3?33
MNZ=J"#D$````)`````4```!'3E4``H``P`0````!`````0`!P`0````)````
M`@`!P`0````!````!````!`````!````1TY5```````#````!``````````1
M````20````0````'`````)$0`)MDA$@(CA`ABH0$R`````!)````3````$\`
M``!0````5@```%<```!8`````````%H`````````6P```%P```!=````7@``
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP,+E/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,S8MOM#3J7"W^IG)OA
MIP(*H^#[20````````````````````#4`0`````````````2````NP(`````
M````````$@````0!`````````````!(```#A`0`````````````2````-P(`
M````````````$@```)8``````````````!(```"+`0`````````````2````
M\`(`````````````$@````D!`````````````!(```#R`0`````````````2
M````&@$`````````````$@```,H"`````````````!(````!````````````
M```@````M0(`````````````$@```!0#`````````````!(````)`@``````
M```````2````PP(`````````````$@```/L!`````````````!(```!+`0``
M```````````2````MP``````````````$@```#L!`````````````!(```#?
M`@`````````````2````8@(`````````````$@```"T!`````````````!(`
M``##`0`````````````2````$```````````````(````*D!````````````
M`!(````L```````````````@````$0(`````````````$@```(<"````````
M`````!(```!&```````````````2````8P``````````````%@```'L!````
M`````````!(```#Z`@`````````````1````=@``````````````$@```-\#
M`````````````!(```#S```````````````2````AP``````````````$@``
M`-$"`````````````!(```!2`@`````````````2````V`(`````````````
M$@```#X"`````````````!(````J`@`````````````2````UP``````````
M````$@```*X"`````````````!(```!,`@`````````````2````;0$`````
M````````$@```.L!`````````````!(```"G`@`````````````2````H`(`
M````````````$0```%\!`````````````!(````8`@`````````````2````
M^`(`````````````$0````X!`````````````!(````?`@`````````````2
M````:@(`````````````$@```(8"`````````````!(````E`@``````````
M```2`````@,`````````````$@```'@"`````````````!(```"B````````
M```````2`````@(`````````````$@```)8!`````````````!(```#F````
M```````````1````M`$`````````````$0```*(!`````````````!(```#9
M`0`````````````2````5`$`````````````$@```%0``````````````!(`
M``".`@`````````````2````60(`````````````$@```,4`````````````
M`!(```#H`P```%5``%T````2``X`*00``%!%0``:#```$@`.`)L"``#@(T``
M"0(``!(`#@!I`P``$#Q```4````2``X`AP,``'!10`")`P``$@`.`$\$```@
M/$``Y`$``!(`#@`8!````,)````````0`!D`>@,``!`^0``D````$@`.`)T#
M``#`0T``:@```!(`#@#T`P```&!```0````1`!``$`0``/`Z0``O````$@`.
M`"0$```TTD```````!``&0`]!```4$1``/4````2``X``P0``-C!0```````
M$``8`,$#``!`/D``VP```!(`#@`V!```Z,%````````0`!@`7`0``.3!0``$
M````$0`8``D$``#P)4``)````!(`#@`%!```V,%````````@`!@`S0,``#!$
M0``>````$@`.`*L#``!@.T``J@```!(`#@!F!```(#]``)$$```2``X``%]?
M9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`%]?
M<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``
M8VQO<V5D:7(`;W!E;C8T`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`
M<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`<W1R<W1R`%]?<W1R;F-P>5]C:&L`
M;6MD:7(`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?
M7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`<W1D97)R
M`&UE;6-H<@!S=')C:'(`8VQO<V4`;W!E;F1I<@!G971U:60`86-C97-S`&UE
M;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A=&EO;@!S=')N8VUP`%]?96YV:7)O
M;@!?7W)E9VES=&5R7V%T9F]R:P!?7W1L<U]G971?861D<@!L:6)P97)L+G-O
M+C4N-#`N,`!L:6)M+G-O+C8`;&EB8RYS;RXV`&QD+6QI;G5X+7@S,BYS;RXR
M`&QI8F-R>7!T+G-O+C(`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`
M6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R
M=`!X<U]I;FET`%]?8G-S7W-T87)T`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T
M80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]I;FET7V5N=@!'3$E"0U\R+C$V`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`O
M=7-R+VQI8G@S,B]P97)L-2\U+C0P+C`O>#@V7S8T+7!L9"UL:6YU>"UG;G5X
M,S(M=&AR96%D+6UU;'1I+T-/4D4``````@`"``$``@`"``$``0`"``(``@`!
M``(``0`"``,``@`"``(``0`!``$``@`"``$``@`!``$``0`"``0``0`!``$`
M`@`!``(``0`!``(``@`"``(``@`!``(``@`!``(``@`"``$``@`"``$``@`"
M``0``@`"``(``0`"``$``0`!``(``@`!``$`!0`"``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0````$``0!)`P``$```
M`"````"6D98&```#`',$`````````0`#`#\#```0`````````+21E@8```4`
M?@0``!````"SD98&```$`(D$```0````EI&6!@```@!S!````````(B_0``&
M"P```````)"_0``&#0```````)B_0``&&@```````*"_0``&'````````*B_
M0``2(````````+"_0``&(0```````+B_0``&(@```````,"_0``&(P``````
M`,B_0``&,@```````-"_0``&0````````-B_0``&00```````."_0``&1@``
M``````#`0``'`0````````C`0``'`@```````!#`0``'`P```````!C`0``'
M!````````"#`0``'!0```````"C`0``'!@```````##`0``'!P```````#C`
M0``'"````````$#`0``'"0```````$C`0``'"@```````%#`0``'#```````
M`%C`0``'#@```````&#`0``'#P```````&C`0``'$````````'#`0``'$0``
M`````'C`0``'$@```````(#`0``'$P```````(C`0``'%````````)#`0``'
M%0```````)C`0``'%@```````*#`0``'%P```````*C`0``'&````````+#`
M0``'&0```````+C`0``'&P```````,#`0``''0```````,C`0``''@``````
M`-#`0``''P```````-C`0``')````````.#`0``')0```````.C`0``')@``
M`````/#`0``')P```````/C`0``'*`````````#!0``'*0````````C!0``'
M*@```````!#!0``'*P```````!C!0``'+````````"#!0``'+0```````"C!
M0``'+@```````##!0``'+P```````#C!0``',````````$#!0``',0``````
M`$C!0``',P```````%#!0``'-````````%C!0``'-@```````&#!0``'-P``
M`````&C!0``'.````````'#!0``'.0```````'C!0``'.@```````(#!0``'
M.P```````(C!0``'/````````)#!0``'/0```````)C!0``'/@```````*#!
M0``'/P```````*C!0``'0@```````+#!0``'0P```````+C!0``'1```````
M`,#!0``'10```````,C!0``'1P```````-#!0``'2```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%A9\``$B%P'0"_]!(@\0(PP```````````/\URI\``/\ES)\`
M``\?0`#_)<J?``!H`````.G@_____R7"GP``:`$```#IT/____\ENI\``&@"
M````Z<#_____);*?``!H`P```.FP_____R6JGP``:`0```#IH/____\EHI\`
M`&@%````Z9#_____)9J?``!H!@```.F`_____R62GP``:`<```#I</____\E
MBI\``&@(````Z6#_____)8*?``!H"0```.E0_____R5ZGP``:`H```#I0/__
M__\E<I\``&@+````Z3#_____)6J?``!H#````.D@_____R5BGP``:`T```#I
M$/____\E6I\``&@.````Z0#_____)5*?``!H#P```.GP_O___R5*GP``:!``
M``#IX/[___\E0I\``&@1````Z=#^____)3J?``!H$@```.G`_O___R4RGP``
M:!,```#IL/[___\E*I\``&@4````Z:#^____)2*?``!H%0```.F0_O___R4:
MGP``:!8```#I@/[___\E$I\``&@7````Z7#^____)0J?``!H&````.E@_O__
M_R4"GP``:!D```#I4/[___\E^IX``&@:````Z4#^____)?*>``!H&P```.DP
M_O___R7JG@``:!P```#I(/[___\EXIX``&@=````Z1#^____)=J>``!H'@``
M`.D`_O___R72G@``:!\```#I\/W___\ERIX``&@@````Z>#]____)<*>``!H
M(0```.G0_?___R6ZG@``:"(```#IP/W___\ELIX``&@C````Z;#]____):J>
M``!H)````.F@_?___R6BG@``:"4```#ID/W___\EFIX``&@F````Z8#]____
M)9*>``!H)P```.EP_?___R6*G@``:"@```#I8/W___\E@IX``&@I````Z5#]
M____)7J>``!H*@```.E`_?___R5RG@``:"L```#I,/W___\E:IX``&@L````
MZ2#]____)6*>``!H+0```.D0_?___R5:G@``:"X```#I`/W___\E4IX``&@O
M````Z?#\____)4J>``!H,````.G@_/___R5"G@``:#$```#IT/S___\E.IX`
M`&@R````Z<#\____)3*>``!H,P```.FP_/___R4JG@``:#0```#IH/S___\E
M(IX``&@U````Z9#\____)1J>``!H-@```.F`_/___R42G@``:#<```#I</S_
M__\E"IX``&@X````Z6#\____)0*>``!H.0```.E0_/___R7ZG0``:#H```#I
M0/S__U53@^PHB7PD#(U\)`R)="0(C70D"(E4)`2-5"0$9(L$)1@```")1"0<
M,<#HH/___XLU<IL``(L]I)L``$B)\N@\,0``BP6FFP``9X`X``^$%P$``&2+
M!"4`````2`,%99L``&>+`&>`B`X#```#BT0D#(UX!8'_____/P^'9@$``,'G
M`N@'____1(M,)`B+5"0,QP6LK0``!````$B)P8D%GZT``$&)P+X!````9T&+
M`6>)`8T%+CT``&>)003'P.3!0`!GBP!GB4$(C04:/0``9XE!#(/Z`7X89@\?
M1```9T&+/+%G08E\L`R#Q@$Y\G7N9T''1)`,`````(L]3JT``(/"`T4QP(TU
M,A8``.B=^___B<.%P`^$A````(L]+:T``(UL)!CHM/W__S'`2(GNC3V,.P``
MZ/0/``!(A<!T<HL]":T``.@D^___Z)_\__^+1"0<9"L$)1@````/A:$```"#
MQ"B)V%M=P^A0_/__B07:K```2(G'A<!T?>B>_/__9(L$)0````!(`P4WF@``
M9XL`9\:`K@4```#IL_[__XL]J:P``.BD^___B</I:O___XL]DZP``(7_=`KH
M7B\``.EZ____C3VK.@``2(GNZ%L/``")!7&L``")QX7`#X1<____Z]:+-0N:
M``"-/8`Z```QP.AV_?__OP$```#H3/K__^BG^___#Q^``````#'M08G1BS0D
M@\0$B>*#Y/!05$4QP#')Q\?@(T``_Q7-F0``]&8N#Q^$``````!FD,-F+@\?
MA```````#Q]$``"-/;*;``"-!:R;```Y^'00BP52F0``A<!T!HG`_^!FD,-F
M9BX/'X0```````\?0`"-/8*;``"--7R;```I_HGPP>X?P?@"`<;1_G04BP4>
MF0``A<!T"HG`_^!F#Q]$``##9F8N#Q^$```````/'T``\P\>^H`]59L```!U
M$U6)Y>A[____Q@5$FP```5W#9I##9F8N#Q^$```````/'T``\P\>^NN*9BX/
M'X0``````$%52(G^05154X'L6`$``&2+!"48````B80D3`$``#'`B>%F#Q]$
M``!GBU2&'`_*9XD4@8/``8/X$'7M\P]^1"0(2(M4)!"-1"1`C;PD0`$``/,/
M?E0D&&8/'X0``````&?S#WY(P&9(#W[1@\`(9_,/?E#89@_OP6?S#WY([&8/
M[\IF#^_!9@]OR&8/<M`?9@]R\0%F#^O!9V8/UD#X9D@/;L)(B<HYQW6V9XLN
M9XM>$(L$)&=$BUX(B>IG1(M.#&=$BU8$08GLP<(%18G8BTPD!$'!S`*-A`.9
M>8):1(ML)`P!T$2)VD&-C`F9>8):1#'*1"'21#'*`=!$B=+!R@)!,=")UT$A
MZ$0QYT4QV"''00'(B<$QU\'(`L'!!4*-E"J9>8):1(ML)!!!`<B+3"0(08V,
M"YEY@EH!ST2)P<'!!0'/1(GA,<%$(<%!P<@"1#'A1XVD+)EY@EI$BVPD%`'1
MB?K!P@4!T8G"1#'"(?HQPD*-A"B9>8):1(ML)!A$`>)!B<Q!P<0%P<\"1`'B
M18G$03'\02',P<D"13'$1XV$*)EY@EI$BVPD'$0!X$&)U$'!Q`5$`>!!B?Q!
M,<Q!(=3!R@)!,?Q"C;POF7F"6D2+;"0@10'@08G$0<'$!44!X$&)S$$QU$$A
MQ,'(`D$QS$*-C"F9>8):1(ML)"1$`>=%B<1!P<0%1`'G08G403'$12'$0<'(
M`D$QU$*-E"J9>8):1(ML)"A$`>%!B?Q!P<0%1`'A08G$13'$02'\P<\"03'$
M0HV$*)EY@EI$BVPD+$0!XD&)S$'!Q`5$`>)%B<1!,?Q!(<S!R0)%,<1'C80H
MF7F"6D2+;"0P1`'@08G40<'$!40!X$&)_$$QS$$AU,'*`D$Q_$*-O"^9>8):
M1(ML)#1%`>!!B<1!P<0%10'@08G,03'402'$P<@"03',0HV,*9EY@EI$BVPD
M.$0!YT6)Q$'!Q`5$`>=!B=1!,<1%(<1!,=1"C90JF7F"6D2+;"0\1`'A08G\
M0<'$!40!X4'!R`)!B<1%,<1!(?S!SP)!,<1"C80HF7F"6D2+;"1`1`'B08G,
M0<'$!40!XD6)Q$$Q_$$AS,')`D4QQ$>-A"B9>8):1(ML)$1$`>!!B=1!P<0%
M1`'@08G\03',02'4P<H"03'\0HV\+YEY@EI$BVPD2$4!Q$&)P$'!P`5%`<1!
MB<A!,=!!(<#!R`)!,<A"C8PIF7F"6D2+;"1,00'X1(GGP<<%00'XB=<QQT0A
MYS'70<',`D*-E"J9>8):`<]$B<'!P04!SXG!1#'A1"'!,<$!RHGYP<$%`<I$
MB<%$BT0D4,')`D:-A`"AZ]EN1(G@,<@Q^,'/`D$!P(G008G]P<`%00'`BT0D
M5$&-O`2AZ]ENB<A$,>@QT`''1(G`P<`%`<>)T(M4)%C!R`*-C!&AZ]EN1(GJ
M08G$,<)$,<)!P<@"`=&)^D4QQ,'"!4$Q_`'1BU0D7$&-E!6AZ]EN1`'B08G,
MP<\"0<'$!40!XD2+9"1@0HV$(*'KV6Y%B<1!,?Q!,<S!R0)$`>!!B=1!P<0%
M1`'@1(MD)&1'C80@H>O9;D&)_$$QS$$QU,'*`D4!X$&)Q$'!Q`5%`>!$BV0D
M:$*-O">AZ]EN08G,03'403'$P<@"1`'G18G$0<'$!40!YT2+9"1L0HV,(:'K
MV6Y!B=1!,<1%,<1!P<@"1`'A08G\0<'$!40!X42+9"1P0HV4(J'KV6Y!B<1%
M,<1!,?Q$`>)!B<Q!P<0%1`'B1(MD)'3!SP)"C80@H>O9;D6)Q$$Q_$$QS,')
M`D0!X$&)U$'!Q`5$`>!$BV0D>$>-A""AZ]EN08G\03',03'4P<H"10'@08G$
M0<'$!44!X$2+9"1\0HV\)Z'KV6Y!B<Q!,=1!,<3!R`)$`>=%B<1!P<0%1`'G
M1(ND)(````!"C8PAH>O9;D&)U$$QQ$4QQ$'!R`)$`>%!B?Q!P<0%1`'A1(ND
M)(0```!"C90BH>O9;D&)Q$4QQ$$Q_,'/`D0!XD&)S$'!Q`5$`>)$BZ0DB```
M`$*-A""AZ]EN18G$03'\03',P<D"1`'@08G40<'$!40!X$2+I"2,````1XVD
M(*'KV6Y!B?A!,<A!,=#!R@)%`<1!B<!!P<`%10'$1(N$))````!&C80'H>O9
M;HG/,=<QQ\'(`D$!^$2)Y\''!4$!^(N\))0```"-O#FAZ]ENB=$QP40QX4'!
MS`(!ST2)P<'!!0'/BXPDF````(V,"J'KV6Z)PD0QXD0QPD'!R`(!T8GZ18G%
MP<(%`=&+E"2<````C900H>O9;D2)X$0QP#'X`<*)R,'/`L'`!4$A_0'"1(G`
M"?@AR,')`D0)Z$2+K"2@````1XVD+-R\&X]!B?U$`>!!B=1!(<U!P<0%1`'@
M08G\00G,02'4P<H"10GL1(NL)*0```!'C80HW+P;CT&)S44!X$&)Q$$AU4'!
MQ`5%`>!!B<Q!"=1!(<3!R`)%">Q$BZPDJ````$*-O"_<O!N/08G51`'G18G$
M02'%0<'$!40!YT&)U$$)Q$4AQ$4)[$2+K"2L````0HV,*=R\&X]!B<5$`>%!
MB?Q!P<@"0<'$!44AQ40!X4&)Q$4)Q$$A_,'/`D4)[$2+K"2P````0HV4*MR\
M&X]%B<5$`>)!B<Q!(?U!P<0%1`'B18G$00G\02',P<D"10GL1(NL)+0```!"
MC80HW+P;CT&)_40!X$&)U$$AS4'!Q`5$`>!!B?Q!"<Q!(=3!R@)%">Q$BZPD
MN````$>-A"C<O!N/08G-10'@08G$02'50<'$!44!X$&)S$$)U$$AQ$4)[$2+
MK"2\````0HV\+]R\&X]!B=5$`>=%B<3!R`)!P<0%02'%1`'G08G400G$12'$
M0<'(`D4)[$2+K"3`````0HV,*=R\&X]!B<5$`>%!B?Q%(<5!P<0%1`'A08G$
M10G$02'\P<\"10GL1(NL),0```!"C90JW+P;CT6)Q40!XD&)S$$A_4'!Q`5$
M`>)%B<1!"?Q!(<S!R0)%">Q$BZPDR````$*-A"C<O!N/08G]1`'@08G402'-
M0<'$!40!X$&)_$$)S$$AU$4)[$2+K"3,````1XV$*-R\&X]!B<U%`>!!B<3!
MR@)!P<0%02'510'@08G,00G402'$P<@"10GL1(NL)-````!"C;POW+P;CT&)
MU40!YT6)Q$$AQ4'!Q`5$`>=!B=1!"<1%(<1!P<@"10GL1(NL)-0```!"C8PI
MW+P;CT&)Q40!X4&)_$4AQ4'!Q`5$`>%!B<1%"<1!(?S!SP)%">Q$BZPDV```
M`$*-E"K<O!N/18G%1`'B08G,02']0<'$!40!XD6)Q$$)_$$AS$4)[$2+K"3<
M````0HV$*-R\&X]!B?U$`>!!B=3!R0)!P<0%02'-1`'@08G\00G,02'4P<H"
M10GL1(NL).````!'C80HW+P;CT&)S44!X$&)Q$$AU4'!Q`5%`>!!B<Q!"=1!
M(<3!R`)%">Q$BZPDY````$*-O"_<O!N/08G51`'G18G$02'%0<'$!40!YT&)
MU$$)Q$4AQ$'!R`)%">Q$BZPDZ````$*-C"G<O!N/08G%00',B?E%(<7!P05!
M`<R)P40)P2'Y1`GI1(NL).P```!"C90JW+P;CP'*1(GAP<\"P<$%08G]`<J+
MC"3P````C8P(UL%BRD2)P#'X1#'@0<',`@'!B=#!P`4!P8N$)/0```!!C;P`
MUL%BRD2)Z$0QX#'0`<>)R,'`!0''B="+E"3X````P<@"18VL%=;!8LI$B>)!
MB<`QPC'*P<D"00'5B?K!P@5!`=6)RHN,)/P```!!,=!!,?A!C8P,UL%BRL'/
M`D2+I"0$`0``1`'!18GH0<'`!40!P42+A"0``0``1HV$`-;!8LJ)T$*-E"+6
MP6+*08G\,?A$,>A!`<")R,'`!4$!P$2)Z,'(`D$QQ$$QS,')`D0!XD6)Q$'!
MQ`5$`>)$BZ0D"`$``$*-O"?6P6+*08G$03',13'$0<'(`D0!YT&)U$'!Q`5$
M`>=$BZ0D#`$``$*-A"#6P6+*08G,13'$03'4P<H"1`'@08G\0<'$!40!X$2+
MI"00`0``0HV,(=;!8LI%B<1!,=1!,?S!SP)$`>%!B<1!P<0%1`'A1(ND)!0!
M``!'C80@UL%BRD&)U$$Q_$$QQ,'(`D4!X$&)S$'!Q`5%`>!$BZ0D&`$``$*-
ME"+6P6+*08G\03'$03',P<D"1`'B18G$0<'$!40!XD2+I"0<`0``0HV\)];!
M8LI!B<1!,<Q%,<1!P<@"1`'G08G40<'$!40!YT2+I"0@`0``0HV$(-;!8LI!
MB<Q%,<1!,=3!R@)$`>!!B?Q!P<0%1`'@1(ND)"0!``!"C8PAUL%BRD6)Q$$Q
MU$$Q_,'/`D0!X4&)Q$'!Q`5$`>%$BZ0D*`$``$>-A"#6P6+*08G403'\03'$
MP<@"10'@08G,0<'$!44!X$2+I"0L`0``0HV4(M;!8LI!B?Q!,<1!,<Q$`>)%
MB<3!R0)!P<0%1`'B1(ND)#`!``!&C:PGUL%BRHG',<]$,<=!P<@"00']B=?!
MQP5!`?V+O"0T`0``C80XUL%BRHG/1#'',=?!R@(!^$2)[\''!0''BX0D.`$`
M`$2-I`'6P6+*1(G`1(GI,=#!R0)$,>A!`<E!`<2)^&9!#V[9P<`%00'$BX0D
M/`$``$4!XHV$!=;!8LIF00]NXD0!P$&)T$$QR$$Q^$0!P$6)X$'!P`5$`<!F
M#V[`B?C!R`)F#V+$1`'8`=-F#V[(9XE>$&8/8LMF#VS!9P\1!HN$)$P!``!D
M*P0E&````'4-@<18`0``6UU!7$%=P^B,[/__9F8N#Q^$``````"005=!5D%5
M05154X/L"$B%_P^$L@```(L%C(H``&=$BR!%A>0/A)\```!G#[8'2(G]28GU
MA,!T!#P]=54QVV=%BS0D187V=#!%B>=F#Q]$``!$B?>)VDB)[N@SZ___A<!U
M"&=!@#P>/71'9T6+=P1!@\<$187V==F#Q`A$B?!;74%<05U!7D%?PP\?A```
M````B?MG#[9#`8/#`83`=`0\/77P*>OKEV8N#Q^$``````!%*>=%C70>`4'!
M_P)G18E]`.NT#Q]$``!%,?;KJ@\?`%-(B?N![*````!DBP0E&````(F$))P`
M```QP(GFZ`[M__^%P'4ZBU0D&('B`/```('Z`$```'0(@?H`H```=2*^`@``
M`$B)W^BCZO__A<`/E,`/ML#K"V8/'X0``````#'`BY0DG````&0K%"48````
M=0B!Q*````!;P^@PZ___055!5%53@>RH````9(L$)1@```")A"2<````,<!(
MA?]T"6>`/P!(B?MU)8N$))P```!D*P0E&`````^%#P$``('$J````%M=05Q!
M7<,/'P#HB^G__T&)Q(7`=,],B>?HG.G__X7`#X2D````9X!X$RZ-:!-U"F>`
M?0$`=-\/'P!G@'@3+@^$G0```$B)W^C=Z___2(GO08G%Z-+K__]!C7P%`NAX
M[/__28GI28G8NO____])B<5(B<>-#>4H```QP+X!````Z-7K__],B>^)YNB+
MZO__3(GO@_C_=!"+1"08)0#P```]`$```'1;Z`[L__],B>_H5NG__TR)Y^C^
MZ/__A<`/A6+___]F#Q]$``!,B>?H2.G__TB)W^APZ___Z0;___\/'P!G@'T!
M+@^%6/___V>`?0(`#X0>____Z4C___\/'T0``.BS_O__ZZ/HW.G__V9F+@\?
MA```````D$%7059!54%454B)_5-(B?.#["ADBP0E&````(E$)!PQP&>`/CUU
M`X/#`4B)W^C>ZO__2(GOC70D&$&)Q#'`Z`W]__](B<=!B<6%P`^$#P$``.BZ
MZO__1#G@#X/A````BT0D&$2+/8Z'``"-#(4`````9P^V10"$P`^$J@$``#P]
M#X2B`0``B>@/'X0``````&</ME`!@\`!A-)T!8#Z/77O*>A"C7P@`D&)S8E,
M)`AG10,OZ`CK__]G08E%`(7`=%AG08L'BTPD"&>+%`AG#[9%`(U-`6>(`CP]
M="*$P'4,ZQQF#Q]$```\/702@\$!@\(!9P^V0?]GB`*$P'7J9\8"/3'`#Q]`
M`&</M@P89XA,`@&#P`&$R77OBT0D'&0K!"48````#X41`0``@\0H6UU!7$%=
M05Y!7\,/'X``````,<!F#Q]$``!G#[84&&=!B%0%`(/``832=>[KO0\?0`!$
MBSV1A@``9T6+-V=!BPZ%R0^$N````$4Q[68/'T0``$2)Z$&#Q0%G0XL4KH72
M=?"--(4,````BP7#F```A<!U7\<%M9@```$```")]^@.ZO__B40D#$B)QX7`
M#X18____0HT,K0````!$B?:)RHE,)`CH:>?__T2+1"0,BTPD"&=!B0=G0\=$
MJ`0`````1(EL)!CI>?[__P\?A```````1(GWZ*CG__]G08D'08G`A<`/A`+_
M__]"C0RM`````.O##Q^``````#'`Z73^__^^"````$4Q[>E;____Z(_G__]F
M9BX/'X0```````\?0`!!5;K_#P``051)B?152(G]C3WD)0``4X'L&!```&2+
M!"48````B80D#!```#'`B>9)B?7H>.G__X7`?A&)PXU`_V>`?!S_`'5/A<!U
M0V2+!"4`````2`,%/(4``$R)XDB)[F>+..@&Y___BX0D#!```&0K!"48````
M=5*!Q!@0``!;74%<05W##Q^$``````")PV8/'T0``(G:OB\```!,B>_H^>?_
M_TB%P'2A9(L$)0````!(`P7=A```B=E,B>I(B>YGBSCHA>?__^N=Z*[F__]F
M9BX/'X0```````\?`(/L"&2+!"4`````2`,%IH0``(L5J(0``(T-`F0``(TU
M!24``&>+.(/$".F!Z/__D%-DBP0E`````$@#!7B$``!GBSB)P^BV____9XL[
MC0UB)@``6\?"<%%``$4QR4F)R(TUWR0``.F5YO__#Q]$``!!5%4Q[5.!["`@
M``!DBP0E&````(F$)!P@```QP(GC1(VD)!`0``#HE.;__T2-#8(D``"-#;$D
M``!(B=]!B<"Z`1```+X!````,<#H4.?__[H`$```3(GF2(G?Z`#H__^%P'@C
MC7@!B</HLN?__TB)QXG%A<!T$(G:3(GFZ"_F__]GQD0=``")Z(N4)!P@``!D
M*Q0E&````'4+@<0@(```6UU!7,/HAN7__V8/'T0``.E+____9F8N#Q^$````
M``!!5T%6055!5$F)_(T])R0``%532(GS@>RX$```9(L$)1@```")A"2L$```
M,<"-="0,Z+KX__^^+P```$R)YXG%Z`OF__](A<!T/DR)YHT][B,``#'`Z$;[
M__]$B>"+E"2L$```9"L4)1@````/A6T!``"!Q+@0``!;74%<05U!7D%?PP\?
M1```3(GG1(TMO",``.@9YO__3(GN2(G?08G&Z.OD__]!B<>%P'2>08/&`6=!
M@#\`#X3'````#Q]$``!$B?N%[702B>](B=[H/^7__X7`#X2)````2(G?Z,_E
M__]G08!\!_\O=1AF#Q]$``"#Z`%G08!\!_\O9T'&!`<`=.Y$`?`]_P\```^/
M.O___XT-("0``+H`$```18GX,<"-G"2@````@^P(O@$```!!5$2-#1@C``!(
MB=_HH.7__XUT)"!(B=_H5.3__UI9A<!U$(M$)"@E`/```#T`@```=$Y,B>XQ
M_^@DY/__08G'A<`/A-/^__]G08`_``^%/O___X7M=`=G@'T`+G031(T]HB(`
M`+@!````Z63___]FD&>`?0$`=+OKY`\?@`````"^`0```$B)W^CSXO__A<!U
MH4B)WHT]=R(``.C1^?__2(G?Z*GD__]!B<3I>_[__^B,X___9F8N#Q^$````
M``"09P^V#X3)=!F)^F8/'T0``(/"`8#Y+V</M@H/1/J$R77OB?C#9F8N#Q^$
M``````"02(7_#X3'````55-(B?N#[`AG@#\`#X2%````Z'#D__^-5!C_.=-R
M#^LK9@\?1```@^H!.=IT>6>`.B]T\SG3<@[K$@\?1```@^H!.=IT86>`.B]U
M\SG:=0WK50\?1```9X`Z+W4'@^H!.=-R\RG:,<"-2@*!^0`0``!W&XT]7H,`
M`(/"`;D`$```2(G>2(G]Z&OC__^)Z(/$"%M=PP\?`(/$"(T];2$``%M=Z;#C
M__]G@#HO=.J#Q`B-/7$A``!;7>F:X___9BX/'X0``````(T]0"$``.F%X___
M#Q]$``!!5T%6055!5$2-)4,A``!54X/L6&8/;P7D7P``9(L$)1@```")1"1,
M,<`QP(UL)!P/*40D(&8/;P737P``2(GK9HE$)$`/*40D,&8/'T0``#'`2(GN
M3(GGZ)/U__](A<!T+HL%,(```(M4)!QGBP"-!)!GBU`$9XD0A=)TTP\?`&>+
M4`B#P`1GB1"%TG7RZ\!$C27$(```B=T/'X``````,<!(B>Y,B>?H0_7__TB%
MP'0NBP7@?P``BU0D'&>+`(T$D&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)$(72
M=?+KP$2-)7P@``")W0\?@``````QP$B)[DR)Y^CS]/__2(7`="Z+!9!_``"+
M5"0<9XL`C0209XM0!&>)$(72=-,/'P!GBU`(@\`$9XD0A=)U\NO`1(TE-2``
M`(G=#Q^``````#'`2(GN3(GGZ*/T__](A<!T+HL%0'\``(M4)!QGBP"-!)!G
MBU`$9XD0A=)TTP\?`&>+4`B#P`1GB1"%TG7RZ\"-+>T?``!!B=P/'X``````
M,<!,B>9(B>_H4_3__TB%P'0NBP7P?@``BU0D'&>+`(T$D&>+4`1GB1"%TG33
M#Q\`9XM0"(/`!&>)$(72=?+KP$2-+:P?``!!B=QF#Q]$```QP$R)YDR)[^@#
M]/__2(7`="Z+!:!^``"+5"0<9XL`C0209XM0!&>)$(72=-,/'P!GBU`(@\`$
M9XD0A=)U\NO`1(TE$1\``$&)W68/'T0``#'`3(GN3(GGZ+/S__](A<!T+HL%
M4'X``(M4)!QGBP"-!)!GBU`$9XD0A=)TTP\?`&>+4`B#P`1GB1"%TG7RZ\!$
MC348'P``08G=9@\?1```,<!,B>Y,B??H8_/__TB%P'0NBP4`?@``BU0D'&>+
M`(T$D&>+4`1GB1"%TG33#Q\`9XM0"(/`!&>)$(72=?+KP$2-+=(>``!!B=]F
M#Q]$```QP$R)_DR)[^@3\___2(7`="Z+!;!]``"+5"0<9XL`C0209XM0!&>)
M$(72=-,/'P!GBU`(@\`$9XD0A=)U\NO`B=A$C3V*'@``2(E$)`AFD$B+="0(
M,<!,B?_HP?+__TB%P'0LBP5>?0``BU0D'&>+`(T$D&>+4`1GB1"%TG31D&>+
M4`B#P`1GB1"%TG7RZ\"-!=L=``!!B=](B40D"&:02(M\)`@QP$R)_NAQ\O__
M2(7`="R+!0Y]``"+5"0<9XL`C0209XM0!&>)$(72=-&09XM0"(/`!&>)$(72
M=?+KP$R)_HT]]!T``.@R\O__A<!T#4B)QDR)[S'`Z-'T__\QP(G>C3WE'0``
MZ!+R__^%P'002(G&C3WE'0``,<#HKO3__TB)WHT]X!T``#'`Z.[Q__](B<:%
MP'0V3(GG,<#HC?3__S'`C37L'0``2(GOZ'WT__^+1"1,9"L$)1@```!U6X/$
M6%M=05Q!74%>05_#,<!(B=Z-/:$=``#HH?'__X7`=`](B<9,B?<QP.A`]/__
MZ[%(N%!!4E]#3$5!2#E$)#%UH&:!?"0Y3CUUEXUT)#M,B?<QP.@6]/__ZX?H
MW]W__V9F+@\?A```````#Q]``(/L&&2+!"48````B40D#(L%"WX``(/X_W06
MBU0D#&0K%"48````=3V#Q!C##Q]``(UT)`B-/;4<```QP.@/\?__2(G",<"%
MTG039P^V`CPP#Y7"A,`/E<`/ML`AT(D%O7T``.NUZ&;=__]F#Q]$``"#[`CH
MV-S__XG'Z*'=__^)PH7`=`-GBQ")T(/$",-FD$%5051$C25*'0``54B)_4R)
MYU.#[!ADBP0E&````(E$)`PQP(UT)`CHD_#__X7`=`9G@#@`=2F+1"0,9"L$
M)1@````/A:<```!(B>Z#Q!A,B><QP%M=05Q!7>D1\___D$B)[DB)QTB)P^BR
MV___2(7`=!V+1"0,9"L$)1@```!U;X/$&%M=05Q!7<,/'T0``$B)[^CHW?__
M2(G?08G%Z-W=__]!C7P%`NB#WO__@^P(NO____])B>A32(G'28G%1(T-6!L`
M`(T-.AP``+X!````,<#HV-W__UA:BT0D#&0K!"48````=0A,B>[I7/___^A+
MW/__9F8N#Q^$``````!!5XT5V!L``$%69@]NPHT5HAL``$%59@]NRHT5>1L`
M`$F)_4%455.![(B!``!DBP0E&````(F$)'R!``"-!<0:``"-="1,QT0D6```
M``#'A"2$`````````$F)],=$)&@`````9@]N\(T%?QL``&8/8L9F#V[XC05I
M&P``9@]N\&8/UD0D4&8/;L)F#V+/9@]BQHT%7AL``(T54QL``&8/;,%F#V[X
MC05<&@``#Q%$)'1F#V["2(G'2(E$)!AF#V+',<!F#]9$)&#H\N[__X7`=`IG
M@#@`#X6L!```,<"-7"1@1(GEZ/;]__](B<=!B<:%P`^$^`$``.B#W/__C7P`
M`>@JW?__9T4/M@9(B<5!B<=%A,!T-XT=XQH```\?0`!$B?]%#[;`2(G9NO__
M__^^`0```#'`08/&`4&#QP+H;=S__V=%#[8&183`==-$C7PD<(T%2!H``$6)
MYNL0#Q\`9T&+1P1!@\<$A<!T.XG'3(GV,<#H1^[__TB)PX7`=.!G@#@`=-I(
MB<?H`N___X7`=,Y(B=_HMMO__T&)P(7`=4</'X``````1(UT)%!G18L&187`
M=#)G08`X``^$CP,``$2)PTB)W^C$[O__A<`/A80!``!G18M&!$&#Q@1%A<!U
MU&8/'T0``$2)PTB)W^B-V___B>I(B==(B50D$$&)QNA[V___18V\!@0$``!$
MB?_H&]S__TB+5"0028G81(T-_!@``$B)!"1(B<>)Q8T%VAD``$R)3"0(C0W&
M&0``O@$```!(B?M2NO____]0,<#H7-O__[[``0``2(G?Z,_:__]!6$%9@_C_
M=1/HH=G__V=$BPA!@_D1#X7;`@``2(L\)(VT))````!)B?;H,-O__XG#A<`/
MA-X```"+!=AW``!G08M-`+X!````C140&@``3(L$)&>+.#'`Z#+;__]%,>2+
MA"1\@0``9"L$)1@````/A3\)``"!Q(B!``!,B>!;74%<05U!7D%?PV8/'T0`
M`&>+.X7_=")(B>XQP.B_[/__2(G'A<!T!F>`.`!U,F>+>P2#PP2%_W7>OPT`
M``!$C36T&```Z`;;__]!N%,```!(B<5!B<?IV_W__P\?1```Z`O:__]!B<:%
MP'3"2(G'Z:3]__\/'T``2(G?08/&!.CLV?__08G`A<`/A#[^___I=/[__P\?
M0`"+A"2H````)0#P```]`$````^%"____XN$)*P```")1"00Z"'8__\Y1"00
M#X7Q_O__BX0DJ````"7_`0``/<`!```/A=K^__]$B?_H:-K__T2)YHT]01@`
M`(E$)!!)B<<QP.CAZ___A<`/A-D!``!(B<?H8=G__V=!BWT`2(G&Z-3R__]!
MB<2%P`^$N0$``$2)Y^AQV?__@_@#=CQ!C7P$_(TU^!<``(E$)"#HN-C__X7`
M=22+5"0@@_H$#X1:!@``9T&`?!3[+P^$308``&8N#Q^$```````QP.@9^O__
MA<!U%$2)YS'VZ&O7__^)QX7`#X5;`0``C35B%P``C3WD%@``,<#H[NW__T2-
M+<P7``!$C36N%P``Z#O8__]!5;K_____3(G_4$R+3"08C0V%%P``,<!,BT0D
M$+X!````Z/38__]86D2+9"003(E\)!!,BWPD".L[D.@[U___9X,X$75!Z/#7
M__^#PP&#[`A$B?%!54V)^4&)Z+K_____4[X!````3(GG4#'`Z*G8__^#Q""^
MP`$``$R)Y^@9V/__@_C_=+1,BWPD$$B+/"3H-M;__TB+?"083(G^,<#H-^W_
M_TR)_^B_^?__Z7O]__]F+@\?A```````13'`Z9#\__^+!1IU``!G08M-`+X!
M````C142%P``3(L$)&>+.#'`Z'38___I/?W__P\?@`````!(B<=(B</H;?G_
M_XN$)'R!``!D*P0E&`````^%;08``('$B($``$B)WUM=05Q!74%>05_ID-?_
M_V=%BV4`Z3W^__^Z`@```$C'QN[___^)1"0@C9PD<`$``.A:V/__BWPD($B)
MWDF)W+H&````Z-;7__^+?"0@@+PD<`$```!U#H"\)'$!``!##X1^!0``,=(Q
M]HE\)"`QV^@;V/__2(L%U%,``&8/;P6\4P``QX0DJ`````````#'A"3L````
M`````$4Q[4B)A"2@````C80DK````$2)[8E$)#!,B7PD.$2)="0T08G>#RF$
M))`````/'X0``````(M\)"!$B>.Z`(```$B)WN@\U___08G%A<`/CC8!``!"
MC03M`````(N4).P````!Z(F$)*0```!$B>A!@]8`P>@=1`'P18GFB80DJ```
M`(72#X6R````08/]/P^.[0,``$&#[4"+;"0T18GO0<'O!D&-7P'!XP9$`?,/
M'X``````9_-!#V\62(GO08/&0&?S00]O7M!G\T$/;V;@9_-!#V]N\`\1E"2L
M````#Q&<)+P````/$:0DS`````\1K"3<````Z$G:__]!.=YUM$2)^L'B!D$I
MU8M\)#")WKE$````1(GJZ)C5__]$B:PD[````(NL)*0```!$B[0DJ````.G\
M_O__#Q]``+A`````2(G>*=!$.>A!#T_%08G&BT0D,(T\$$2)\N@5U?__BX0D
M[````$0!\(F$).P```"#^$!UKXM\)#1%*?5%`>;HP-G__^D!____BWPD($R+
M?"0X1(GS08GM1(MT)#3HHM/__XGHBU0D,,'H`X/@/V?&A`2L````@(UP`0'R
M@_XX#X[$`@``OT`````I]W0G,<!`]L<!=`VX`0```&?&`@`Y^',29\8$`@!G
MQD0"`0"#P`(Y^'+N1(GWZ$?9__]F#^_`2,>$)-P`````````#Q&$)*P````/
M$80DO`````\1A"3,````00^VQ42)ZD6)Z46)Z`^VUDC!X`@/ML^)WT'!Z1!(
M"=!!P>@8B=Y(P>`(00^VT44/ML#![Q!("=`/MM-`#[;_P>X82,'@"$`/MO9,
M"<!(P>`(2`G02,'@"$@)R$C!X`A("?A$B?=(P>`(2`GP2(F$).0```#HIMC_
M_XNT))0```"+G"20````BY0DF````(N,))P```!$#[;VB?!!B?)!B?,/MO1,
MB?!!P>L0B=](P>`(10^VVT'!ZAA!B=E("?!!B=5!B=2)S4C!X`A!B<A%#[;2
MP>\83`G80<'I$`^V\P^VWTC!X`A!P>T810^VR4`/MO]!P>P0P>T810^V[42-
MM"1``0``0<'H$$P)T$`/MNU%#[;D2,'@"$4/ML!("?!(P>`(2(G&#[;!#[;-
M2,'@"$@)WHT=51(``$@)R`^VR@^VUDC!Y@A(P>`(3`G.3`G`2,'F"$C!X`A(
M"?Y(">A(B70D((VL)&@!``!(P>`(2`G(2,'@"$@)T$C!X`A,">!%B?1(P>`(
M3`GH1(VL)"`!``!(B40D*(N$)*````!F#V],)"`/R(F$)#`!```/*8PD(`$`
M``\?`&=%#[9%`$2)YTB)V3'`NO____^^`0```$&#Q`)!@\4!Z&/3__]!.>QU
MUL:$)&@!````C07U$0``4$%63(M,)!B^`0```$R)_S'`3(M$)!"-#:01``"Z
M_____^@IT___65Y$BV0D$.F.^O__9T6+;01%A>T/A*_Y__]$B>_HU]+__X/X
M`P^&GOG__T&-?`7\C35?$0``Z![2__^%P$4/1.7I@_G__T2)\^F`_/__N#@`
M``!%,<`I\(/X"',LJ`0/A10!``"%P`^$??W__V?&`@"H`@^$<?W__S'_9V:)
M?`+^Z63]__\/'P"-<@AG2,<"`````&=(QT0"^`````"#YO@I\@'0@^#X@_@(
M#X(Y_?__1(U(_T&)PK\(````9TC'!@````!!P>D#08/B^$&#X0$YQP^#$?W_
M_T6%R7079TC'1@@`````OQ````!$.=</@_7\__]G3(D$/F=,B40^"(/'$$0Y
MUW+MZ=W\__^`O"1R`0``00^%=/K__X"\)',!``!##X5F^O__@+PD=`$``$@/
MA5CZ__^`O"1U`0``10^%2OK__[H"````2,?&QO___^ACTO__BWPD(+HI````
M2(G>Z.+1__^-!6$0``!04^EH_O__#Q]$``!GQP(`````9\=$`OP`````Z5S\
M___H)M#__V8/'T0``$%7059!54%455.#[!ADBP0E&````(E$)`PQP&2+!"4`
M````2`,%#FX``(UT)`B-/>\.``!)B?5GBQAG#[9#9&>(0V4QP.A6X___A<!T
M"F>`.#$/A-`"```QP.A1[?__9(L$)0````!(`P7*;0``9XL8B=^Y"P```+H!
M````C36L#P``Z%C/__^%P`^$%P$``&>+0`QG1(M@&&2+!"4`````2`,%D&T`
M`(,]"8````%GBQ@/C@$!```Q[>M%#Q]``$2)_HG?N0(````QTNB/T?__9T&+
M'HG&BP77?P``1(UU`6>+?*@$Z-7/__]$BSW&?P``A<!U:X/%`D$Y[T2)]7Y@
M,<F)WXGJ3(GFZ!'0__^%P'0U9T2+.&2+!"4`````2`,%$FT``&>+&$&)QF=!
MBT<()0`$(``]``0``'6#9T&+=PSKDP\?0`!DBP0E`````$@#!>%L``!$BSU:
M?P``9XL808U'_SG%=5!!@_\!?DJ]`0```.L<9BX/'X0``````&2+!"4`````
M2`,%J6P``&>+&(G?3(GF@\4!Z#'.__\Y+1-_``!_V62+!"4`````2`,%@FP`
M`&>+&(G?N0,```"Z`0```(TU:0X``.@0SO__B<6%P'0\9XM`#&=$BR!DBP0E
M`````$@#!4ML``"-%4,.``!,B>9GBSB)P^@0SO__9XM%#&>+`&?V0`I`#X5(
M`0``9(L$)0````!(`P47;```N0,```"Z`0```(TU"@X``&>+.(G#Z*7-__^)
MQ87`="I$B>Z-/:<,```QP.A/X?__2(G"A<`/A.0```!GBT4,9XL[9XLPZ*7-
M__]DBP0E`````$@#!;YK``"Z`0```(TUN`T``&>+.(G#Z(',__]GBSN-%;H-
M``!(B<;H<,W__V>+`T2)[HT]/`P``&?&0&4`,<#HZ.#__XD%_GT``(G"A<!T
M/(G3OL`!``!(B=_H/<[__XU0`8/Z`78)@_@1#X6*````BT0D#&0K!"48````
M=7>#Q!A;74%<05U!7D%?PXL]KGT``.C5\/__B06K?0``B<*%P'6MC3W;#0``
MZ+[.__]F#Q]$``!G@'@!``^$/OW__^D@_?__#Q^$``````"+!6Y]``!GBS!G
MBT4,9XLXZ$OE___I$?___V>+.XG&Z`S.___IJ?[__^BRS/__BQ5`?0``B<&-
M/:0-```QP&>+,DB)VNA7SO__#Q^``````%532(G[@^P(Z#/I__](B<?H^^C_
M_TB)Q3'`Z*'N__](A=MT(87`=!UG@#L`=!>Z!````(TU)`P``$B)[^A?R___
MA<!T"X/$"%M=PP\?1```@\0(2(G?6UWI`^'__P\?`(L-=FP``.G%S?__`$B#
M[`A(@\0(PP``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`4UE35$5-`"]T;7``
M5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#4`+64`+2T````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`$C
M16>)J\WO_MRZF'94,A#PX=+#``````$;`SO0````&0```,B`__\L`0``B(3_
M_R0&``"8AO__[````,B&__\8`0``B(?__U`!``"XE?__D`$``(B6___<`0``
M")?__P`"``!HF/__/`(``+B:__^(`@``F)O__\0"``#(F___W`(```B<___X
M`@``N)S__RP#``#(G/__0`,``+B>__^@`P``Z)[__[0#``#(G___^`,``&BD
M__](!```V*3__V0$``#XI/__?`0``/BE___4!```&++__Z0%``"HM?__\`4`
M``BV__]0!@``%``````````!>E(``7@0`1L,!PB0`0<0$````!P```"DA?__
M)``````````4``````````%Z4@`!>!`!&PP'")`!```0````'````*B%__\!
M`````````"`````P````E'___\`#````#A!&#AA*#PMW"(``/QH[*C,D(CP`
M``!4````,(;__R0.````0@X0C0)%#AB,`T$.((8$00XH@P5&#H`#`PD."@XH
M00X@00X80@X00@X(00L```!(````E````""4___-`````$(.$(\"0@X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!T,.0`)M"@XX1`XP00XH0@X@0@X80@X00@X(
M20L`(````.````"DE/__@`````!!#A"#`DD.L`$";PH.$$$."$$+.`````0!
M````E?__5`$```!"#A"-`D(.&(P#00X@A@1!#BB#!48.T`%Z"@XH00X@00X8
M0@X00@X(1`L`2````$`!```DEO__00(```!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&1`XX@P=&#F`#&P$*#CA!#C!!#BA"#B!"#AA"#A!"#@A("S@```",
M`0``*)C__](`````0@X0C0)'#AB,`T0.((8$2@XH@P5&#L`@`F0*#BA!#B!!
M#AA"#A!"#@A)"Q0```#(`0``S)C__R\`````0PX09PX(`!@```#@`0``Y)C_
M_SL`````00X0@P)C#@@````P````_`$```B9__^J`````$(.$(P"00X8A@-#
M#B"#!$8.P$`"E`H.($$.&$$.$$(."$$+$````#`"``"$F?__!0````````!<
M````1`(``("9___D`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%2@XPA@9!#CB#
M!TD.\"$"7`H..$$.,$$.*$(.($(.&$(.$$(."$8+`J(.^"%'#H`B7`[X(4$.
M\"$````0````I`(``!";__\D`````````$````"X`@``+)O__]L`````2@X0
MA@)!#AB#`T8.(`*)"@X800X000X(1`M#"@X81\,.$$'&#@A%"TD.&$?##A!!
MQ@X(3````/P"``#(F___D00```!"#A"/`D(.&(X#0@X@C01"#BB,!4@.,(8&
M00XX@P=##I`!`R`$"@XX00XP00XH0@X@0@X80@X00@X(00L````8````3`,`
M`!B@__]J`````$,.(&@*#@A%"P``%````&@#``!LH/__'@````!##A!:#@@`
M5````(`#``!TH/__]0````!"#A"-`D(.&(P#2`X@A@1'#BB#!4,.0'D*#BA&
M#B!!#AA"#A!"#@A&"V0*#BA!#B!!#AA"#A!"#@A&"V`.2$D.4&`.2$$.0,P`
M``#8`P``'*'__QH,````0@X0CP)(#AB.`TP.((T$3PXHC`5!#C"&!D$..(,'
M1@[`@P(#&@(.R(,"1@[0@P)6#LB#`D(.P(,"`G<*#CA$#C!!#BA"#B!"#AA"
M#A!"#@A'"P.G`0[(@P))#M"#`ET.R(,"00[`@P)H#LB#`D4.T(,"3`[8@P))
M#N"#`DH.P(,"`J0*#CA$#C!!#BA"#B!"#AA"#A!"#@A%"P.A!`[(@P)"#M"#
M`F4.R(,"00[`@P(#;`$*#LB#`D$.T(,"2@M(````J`0``&RL__^)`P```$(.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T,.4`/H`@H..$$.,$$.*$(.
M($(.&$(.$$(."$$+,````/0$``"PK___70````!!#A"&`D$.&(,#1@X@`D`*
M#AA!#A!!#@A&"T,.&$0.$$$.""@````H!0``7'[__PD"````00X0A@)!#AB#
M`T,.0`-A`0H.&$,.$$$."$$+$````%0%``"PK___"P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-`F0`"@)D```0```",#```!````-0,```$````_
M`P```0```$D#```!````6P,```\```"4!```#``````@0``-````;%5``!D`
M``!POD``&P````0````:````=+Y``!P````$````]?[_;T@"0``%````]`A`
M``8````$`T``"@```-<$```+````$````!4``````````P```.B_0``"````
MQ`(``!0````'````%P```'P/0``'````[`Y```@```"0````"0````P```#^
M__]OC`Y``/___V\"````\/__;\P-0```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!XOD``````````````
M```````````````V($```````$8@0```````5B!```````!F($```````'8@
M0```````AB!```````"6($```````*8@0```````MB!```````#&($``````
M`-8@0```````YB!```````#V($````````8A0```````%B%````````F(4``
M`````#8A0```````1B%```````!6(4```````&8A0```````=B%```````"&
M(4```````)8A0```````IB%```````"V(4```````,8A0```````UB%`````
M``#F(4```````/8A0```````!B)````````6(D```````"8B0```````-B)`
M``````!&(D```````%8B0```````9B)```````!V(D```````(8B0```````
MEB)```````"F(D```````+8B0```````QB)```````#6(D```````.8B0```
M````]B)````````&(T```````!8C0```````)B-````````V(T```````$8C
M0```````5B-```````!F(T```````'8C0```````AB-```````"6(T``````
M`*8C0```````MB-```````#&(T```````-8C0`````````````````#_____
MV&)``$=#0SH@*%!,1"U,:6YU>"D@,3,N,BXP(#(P,C,P-S(W("AR96QE87-E
M*0!'0T,Z("A03$0M3&EN=7@I(#$S+C,N,"`R,#(T,#4R,2`H<F5L96%S92D`
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92YG
M;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````
M```````````````````````````````````````````+`````0````(```"T
M`4``M`$``!H```````````````$`````````$P````<````"````T`%``-`!
M```D```````````````$`````````"8````'`````@```/0!0`#T`0``-```
M````````````!``````````Y````!P````(````H`D``*`(``"``````````
M``````0`````````1P```/;__V\"````2`)``$@"``"\````!@`````````$
M````!````%$````+`````@````0#0``$`P``\`4```<````!````!````!``
M``!9`````P````(```#T"$``]`@``-<$``````````````$`````````80``
M`/___V\"````S`U``,P-``"^````!@`````````"`````@```&X```#^__]O
M`@```(P.0`",#@``8`````<````"````!`````````!]````!`````(```#L
M#D``[`X``)`````&``````````0````,````AP````0```!"````?`]``'P/
M``#$`@``!@```!<````$````#````)$````!````!@`````@0```(```%P``
M````````````!`````````",`````0````8````@($``("```,`#````````
M`````!`````0````EP````$````&````X"-``.`C``"+,0`````````````0
M`````````)T````!````!@```&Q50`!L50``"0``````````````!```````
M``"C`````0````(`````8$```&```%@_`````````````!``````````JP``
M``$````"````6)]``%B?``#4```````````````$`````````+D````!````
M`@```"R@0``LH```E`4`````````````!`````````##````#@````,```!P
MOD``<*X```0```````````````0````$````SP````\````#````=+Y``'2N
M```$```````````````$````!````-L````&`````P```'B^0`!XK@``$`$`
M``<`````````!`````@```#D`````0````,```"(OT``B*\``&``````````
M``````@````(````Z0````$````#````Z+]``.BO``#P`0`````````````(
M````"````/(````!`````P```-C!0`#8L0``$```````````````!```````
M``#X````"`````,`````PD``Z+$``#00`````````````"``````````_0``
M``$````P`````````.BQ``!6```````````````!`````0````$````#````
@```````````^L@``!@$``````````````0``````````
